#
# Copyright (c) Microsoft. All rights reserved.
# Licensed under the MIT license. See LICENSE file in the project.
#
"""constants."""

DEFAULT_INPUT_NAME = "source"
DEFAULT_OUTPUT_NAME = "result"
